LibRunebox = LibRunebox or {}

local p = function(...)
	df(...)
end

function LibRunebox:IsRuneboxCollected(runeboxItemId)
	return IsCollectibleUnlocked(self.Masterlist[ runeboxItemId ])
end

function LibRunebox:GetRuneboxCollectibleId(runeboxItemId)
	return self.Masterlist[ runeboxItemId ]
end

function LibRunebox:GetRuneboxFragments(runeboxItemId)
	return self.RuneboxToFragments[ runeboxItemId ]
end

function LibRunebox:GetRuneboxForFragment(fragmentItemId)
	return self.FragmentsToRunebox[ fragmentItemId ]
end

local ITEM_LINK_TEMPLATE = "|H1:item:%d:124:1:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h"
local FRAGMENT_ITEM_LINK_TEMPLATE = "|H1:item:%d:5:1:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h"
function LibRunebox:CollectAndDump()
	
	p("Collecting runeboxes...")
	local MAX_ITEM_ID = 160000
	local runeboxes = {}
	local names = {}
	local fragments = {}
	
	local link, itemType, specType, collectibleId
	for id=1, MAX_ITEM_ID do
		link = ITEM_LINK_TEMPLATE:format(id)
		itemType, specType = GetItemLinkItemType(link)
		if itemType == ITEMTYPE_CONTAINER then
			collectibleId = GetItemLinkContainerCollectibleId(link) 
			if collectibleId > 0 then 
				runeboxes[id] = collectibleId
				names[id] = zo_strformat(SI_COLLECTIBLE_NAME_FORMATTER, GetCollectibleName(collectibleId))
			end
		elseif specType == SPECIALIZED_ITEMTYPE_TROPHY_RUNEBOX_FRAGMENT then
			fragments[id] = link
		end
	end
	
	--p(fragments)
	
	local runeboxFragments = {}
	local flavorText
	for fragmentId, fragmentLink in pairs(fragments) do
		flavorText = GetItemLinkFlavorText(fragmentLink)
		for runeboxId, name in pairs(names) do
			if name ~= "" and string.find(flavorText, name, 1, true) then
				runeboxFragments[runeboxId] = runeboxFragments[runeboxId] or {}
				--p("%s -> %s", FRAGMENT_ITEM_LINK_TEMPLATE:format(fragmentId), ITEM_LINK_TEMPLATE:format(runeboxId))
				table.insert(runeboxFragments[runeboxId], fragmentId)
			end
		end
	end
	
	--for itemId, collectibleId in pairs(runeboxes) do
	--	p("[%d] = %d, -- %s", itemId, collectibleId, ITEM_LINK_TEMPLATE:format(itemId))
	--end
	
	p("Runeboxes with fragments....")
	for runeboxId, fragments in pairs(runeboxFragments) do
		if #fragments ~= 7 then
			--p("Invalid fragments for %s", ITEM_LINK_TEMPLATE:format(runeboxId))
		else
			p("[%d] = -- %s", runeboxId, ITEM_LINK_TEMPLATE:format(runeboxId))
			p("{")
			for _, fragmentId in ipairs(fragments) do
				p("..%d, -- %s", fragmentId, FRAGMENT_ITEM_LINK_TEMPLATE:format(fragmentId))
			end
			p("},")
		end
	end
	
end


-- Fix GetItemLinkContainerCollectibleId returning the wrong collectible for [Runebox: Mummified Alfiq Pet] (|H1:item:147928:124:1:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h)
local orgGetItemLinkContainerCollectibleId = GetItemLinkContainerCollectibleId
GetItemLinkContainerCollectibleId = function(itemLink)
	if itemLink == "|H1:item:147928:124:1:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0:0|h|h" then
		return 6381
	end
	return orgGetItemLinkContainerCollectibleId(itemLink)
end